/*
 * This file is part of Locutil1.
 * 
 * Copyright (c) 2007 Thomas King <king@informatik.uni-mannheim.de>,
 * University of Mannheim, Germany
 * 
 * All rights reserved.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.locutil1;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;

/**
 * @author abiskop
 */
public class LoggingStream extends PrintStream {

	private static final boolean createNotificationFile = true;
	private static final String keyWord = "FAILURES!!!";
	private static final String notificationFileName = "failures";
	private static OutputStream sysOut = System.out;
	private PrintStream console = new PrintStream(sysOut);
	private PrintStream logFile;

	private LoggingStream() throws FileNotFoundException {
		this(null);
	}
	
	public LoggingStream(String fileName) throws FileNotFoundException {
		super(sysOut);
		logFile = new PrintStream(new FileOutputStream(fileName));
	}
	
	public void println(String x) {
		if (createNotificationFile) {
			if (x.indexOf(keyWord) != -1) {
				File file = new File(notificationFileName);
				try {
					file.createNewFile();
				} catch (IOException e) {
					System.out.println("failed to create notification file");
				}
			}
		}
		console.println(x);
		logFile.println(x);
	}
}
