/*
 * This file is part of Locutil1.
 * 
 * Copyright (c) 2007 Thomas King <king@informatik.uni-mannheim.de>,
 * University of Mannheim, Germany
 * 
 * All rights reserved.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.locutil1;

import java.util.Hashtable;

import org.pi4.locutil1.MACAddress;

import j2meunit.framework.*;

/**
 * @author king
 */
public class MACAddressTest extends TestCase {
	
	public MACAddressTest() {
	}
	
	public MACAddressTest(String name, TestMethod testMethod) {
		super(name, testMethod);
	}
	
	public void testParse() {
		String address = "00:10:60:A5:33:1B";
		MACAddress ba = MACAddress.parse(address);
		assertTrue(ba.toString().equalsIgnoreCase(address));
	}
	
	public void testHashcode() {
		String address1 = "00:00:00:00:00:10";
		String address2 = "00:00:00:00:00:0F";
		String address3 = "00:00:00:00:00:10";
		MACAddress ba1 = MACAddress.parse(address1);
		MACAddress ba2 = MACAddress.parse(address2);
		MACAddress ba3 = MACAddress.parse(address3);
		assertTrue(ba1.hashCode() != ba2.hashCode());
		assertTrue(ba1.hashCode() == ba3.hashCode());
		
		String address4 = "01:02:00:00:00:10";
		MACAddress ba4 = MACAddress.parse(address4);
		assertTrue(!ba4.equals(ba3));
		assertEquals(ba4.hashCode(), ba3.hashCode());
		Hashtable ht = new Hashtable();
		ht.put(ba3, ba3);
		ht.put(ba4, ba4);
		//System.out.println(ht.size());
		assertEquals(ht.size(), 2);
	}
	
	public Test suite() {
		TestSuite suite = new TestSuite();
		suite.addTest(new MACAddressTest("testParse", new TestMethod() {
			public void run(TestCase tc) { 
				((MACAddressTest) tc).testParse();
			}
		}));
		suite.addTest(new MACAddressTest("testHashcode", new TestMethod() {
			public void run(TestCase tc) { 
				((MACAddressTest) tc).testHashcode();
			}
		}));
		return suite;
	}
}
